<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 * @return array An array of default values
 */

function raise_charity_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$raise_charity_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#666',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff6633',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		//body typography
		'body_font_family'			=> 'Muli',
		'body_font_weight'			=> 300,
		'body_font_size'			=> 16,
		'body_font_style'			=> 'normal',
		'body_text_transform'		=> 'none',

		//h1 typography
		'heading_h1_font_family'		=> 'Raleway',
		'heading_h1_font_weight'		=> 300,
		'heading_h1_text_transform'		=> 'none',
		'heading_h1_font_style'			=> 'normal',

		//h2 typography
		'heading_h2_font_family'		=> 'Raleway',
		'heading_h2_font_weight'		=> 700,
		'heading_h2_text_transform'		=> 'none',
		'heading_h2_font_style'			=> 'normal',

		//h3 typography
		'heading_h3_font_family'		=> 'Raleway',
		'heading_h3_font_weight'		=> 700,
		'heading_h3_text_transform'		=> 'none',
		'heading_h3_font_style'			=> 'normal',

		//h4 typography
		'heading_h4_font_family'		=> 'Raleway',
		'heading_h4_font_weight'		=> 700,
		'heading_h4_text_transform'		=> 'none',
		'heading_h4_font_style'			=> 'normal',

		//h5 typography
		'heading_h5_font_family'		=> 'Raleway',
		'heading_h5_font_weight'		=> 700,
		'heading_h5_text_transform'		=> 'none',
		'heading_h5_font_style'			=> 'normal',

		//h6 typography
		'heading_h6_font_family'		=> 'Raleway',
		'heading_h6_font_weight'		=> 700,
		'heading_h6_text_transform'		=> 'none',
		'heading_h6_font_style'			=> 'normal',

		//p typography
		'heading_p_font_family'			=> 'Muli',
		'heading_p_font_weight'			=> 400,
		'heading_p_text_transform'		=> 'none',
		'heading_p_font_style'			=> 'normal',

		//button
		'button_background_color'		=> '#e5f8fc',
		'button_text_color'		=> '#00afe9',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		
		//menu
		'menu_sticky'					=> false,
		'search_icon'					=> true,
		'nav_btn'						=> true,
		'nav_btn_txt' 					=> esc_html__( 'Donate Now', 'raise-charity-pro' ),
		'nav_btn_url' 					=> '#',

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'raise-charity-pro' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> true,
		'footer_section'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'all_sortable' 						=> 'slider,about,featured_posts,popular_posts,recent_posts,courses,recent_cause,service,event,promotion,gallery,counter,team,skills,testimonial,latest_posts,sponsor,cta,latest_products,popular_products,collection,recent_products,featured_products,trending_product,contact',

		// homepage sections sortable
		'default_sortable' 						=> 'slider,about,recent_cause,service,event,promotion,gallery,counter,team,testimonial,latest_posts,sponsor,cta,contact',
		
		'second_sortable' 						=> 'slider,about,service,team,promotion,gallery,counter,skills,testimonial,latest_posts,sponsor,contact',

		'third_sortable' 						=> 'slider,about,courses,service,promotion,gallery,counter,skills,team,testimonial,latest_posts,sponsor,contact',

		'fourth_sortable' 						=> 'slider,featured_posts,popular_posts,recent_posts,promotion,latest_posts',

		'fifth_sortable' 						=> 'slider,latest_posts,sponsor,latest_products,popular_products,collection,recent_products,featured_products,trending_product,promotion,sponsor',

		'sixth_sortable' 						=> 'slider,about,service,promotion,gallery,counter,team,testimonial,latest_posts,sponsor,contact',

		'seventh_sortable' 						=> 'slider,featured_posts,promotion,gallery,service,event,cta,latest_products,contact',


		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'raise-charity-pro' ),
		'single_post_hide_banner'		=> false,
		'hide_date' 					=> false,
		'hide_banner'					=> false,		
		'blog_page_column'					=> 'col-2',
		'blog_page_post_btn' 			=> esc_html__( 'Read More', 'raise-charity-pro' ),

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		//top bar
		'topbar_section_enable'				=> true,
		'social_menu_enable'				=> true,
		'secondary_menu_enable'				=> true,

		// Slider
		'slider_section_enable'		=> true,
		'slider_autoplay'			=> false,
		'slider_content_type'		=> 'post',
		'slider_count'				=> 3,
		'slider_excerpt_length'		=> 30,
		'slider_btn_label'			=> esc_html__( 'Read More', 'raise-charity-pro' ),

		// about
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'Who Are We', 'raise-charity-pro' ),
		'about_description'				=> esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour, or randomised words which dont look even slightly believable. If you are going to use a passage of Lorem Ipsum, you need to be sure there isnt anything embarrassing hidden in the middle of text.', 'raise-charity-pro' ),
		'about_information_text'		=> esc_html__( 'More Than 365000+ People Were Helped', 'raise-charity-pro' ),
		'about_btn_title'				=> esc_html__( 'Become A Volunteer', 'raise-charity-pro' ),
		'about_excerpt_length'			=> 55,

		// Recent Causes
		'recent_cause_section_enable'		=> true,
		'recent_cause_title'				=> esc_html__( 'Our Recent Causes', 'raise-charity-pro' ),
		'recent_cause_sub_title'			=> esc_html__( 'Children and poor people are at high risk of severe malnutrition & no education.', 'raise-charity-pro' ),
		'recent_cause_content_type'			=> 'post',
		'recent_cause_count'				=> 3,
		'recent_cause_excerpt_length'		=> 30,
		'recent_cause_column_layout'		=> 'col-3',
		'recent_cause_btn_label'			=> esc_html__( 'Explore More', 'raise-charity-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_excerpt_length'		=> 15,
		'service_title'					=> esc_html('How Can You Help Us', 'raise-charity-pro'),
		'service_sub_title'				=> esc_html('Children and poor people are at high risk of severe malnutrition & no education.', 'raise-charity-pro'),

		// event
		'event_section_enable'			=> true,
		'event_title'					=> esc_html('Upcoming Events', 'raise-charity-pro'),
		'event_sub_title'				=> esc_html('Children and poor people are at high risk of severe malnutrition & no education.', 'raise-charity-pro'),
		'event_content_type'			=> 'category',
		'event_count'					=> 4,
		'event_excerpt_length'			=> 15,

		//promotion
		'promotion_section_enable'			=> true,
		'promotion_content_type'			=> 'page',
		'promotion_excerpt_length'			=> 10,
		'promotion_title'					=> esc_html('We help thousands of children, arrange food & build houses for them', 'raise-charity-pro'),
		'promotion_description'				=> esc_html('Join us and Become a Volunteer', 'raise-charity-pro'),
		'promotion_button'					=> esc_html('Join Now', 'raise-charity-pro'),

		// gallery
		'gallery_section_enable'		=> true,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 9,
		'gallery_title'					=> esc_html__( 'Charity Heart Gallery', 'raise-charity-pro' ),
		'gallery_subtitle'				=> esc_html__( 'Children and poor people are at high risk of severe malnutrition & no education.', 'raise-charity-pro' ),

		//counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',

		// team
		'team_section_enable'		=> true,
		'team_content_type'			=> 'category',
		'team_count'				=> 3,
		'team_title'				=> esc_html('Meet Our Volunteers', 'raise-charity-pro'),
		'team_sub_title'			=> esc_html('Children and poor people are at high risk of severe malnutrition & no education.', 'raise-charity-pro'),
		'team_column'				=> 'col-3',

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_auto_play'			=> false,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,	
		'testimonial_excerpt_length'	=> 35,

		// latest_posts
		'latest_posts_section_enable'	=> true,
		'latest_posts_content_type'		=> 'category',
		'latest_posts_count'			=> 3,
		'latest_posts_title'			=> esc_html__( 'Latest News Update', 'raise-charity-pro' ),
		'latest_posts_sub_title'		=> esc_html__( 'Children and poor people are at high risk of severe malnutrition & no education.', 'raise-charity-pro' ),
		'latest_posts_btn_text'			=> esc_html__( 'Read More', 'raise-charity-pro' ),
		'latest_posts_excerpt_length'	=> 15,

		// Contact Us
		'contact_section_enable'		=> true,
		'contact_title'					=> __( 'Get in Touch', 'raise-charity-pro' ),
		'contact_sub_title'				=> __( 'Children and poor people are at high risk of severe malnutrition & no education.', 'raise-charity-pro' ),
		'contact_form_shortcode'		=> __( '[contact-form-7 id="3088" title="Untitled"]', 'raise-charity-pro' ),

		//Sponsor
		'sponsor_section_enable'		=> true,
		'sponsor_title'					=> __( 'Our Sponsors', 'raise-charity-pro' ),
		'sponsor_sub_title'				=> __( 'Children and poor people are at high risk of severe malnutrition & no education.', 'raise-charity-pro' ),
		'sponsor_count'					=> 5,

		// cta
		'cta_section_enable'			=> true,
		'cta_content_type'			=> 'page',
		'cta_title'					=> esc_html__( 'Join 100000+ people raising money for personal causes on Crowdngo', 'raise-charity-pro' ),
		'cta_btn_title'				=> esc_html__( 'Donate Now', 'raise-charity-pro' ),

		//skills
		'skills_section_enable'		=> true,
		'skills_count'				=> 5,
		'skills_title'				=> esc_html__( 'My Career', 'raise-charity-pro' ),
		'skills_sub_title'			=> esc_html__( 'Designs the experience in 3 steps, each increasing in detail, from the flow to the wireframes.', 'raise-charity-pro' ),
		'skills_content'			=> esc_html__( ' Quisque sodales purus sit amet libero pellentesque cursus. Sed blandit nisl purus, ac rutrum risus bibendum interdum. Quisque tincidunt sapien non lorem rhoncus euismod. Nullam hendrerit dapibus volutpat. Nunc at egestas eros. Cras ultrices libero lorem. Mauris hendrerit ut lectus id pellentesque. Nam rutrum condimentum rutrum. Nulla id ante nibh. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.', 'raise-charity-pro' ),

		// courses
		'courses_section_enable'	=> true,
		'courses_content_type'		=> 'category',
		'courses_count'				=> 3,
		'courses_title'				=> esc_html__( 'Featured Courses', 'raise-charity-pro' ),
		'courses_sub_title'			=> esc_html__( 'Children and poor people are at high risk of severe malnutrition & no education.', 'raise-charity-pro' ),
		'courses_btn_text'			=> esc_html__( 'Know Details', 'raise-charity-pro' ),
		'courses_excerpt_length'	=> 20,

		// featured_posts
		'featured_posts_section_enable'		=> true,
		'featured_posts_content_type'		=> 'category',
		'featured_posts_count'				=> 3,
		'featured_posts_column_layout'		=> 'col-3',

		// popular_posts
		'popular_posts_section_enable'		=> true,
		'popular_posts_content_type'		=> 'category',
		'popular_posts_count'				=> 4,
		'popular_posts_title'				=> esc_html__( 'Popular Posts', 'raise-charity-pro' ),
		'popular_posts_sub_title'			=> esc_html__( 'Designs the experience in 3 steps, each increasing in detail, from the flow to the wireframes.', 'raise-charity-pro' ),
		'popular_posts_btn_text'			=> esc_html__( 'Read More', 'raise-charity-pro' ),
		'popular_posts_excerpt_length'		=> 15,

		// recent_posts
		'recent_posts_section_enable'		=> true,
		'recent_posts_content_type'			=> 'category',
		'recent_posts_count'				=> 3,
		'recent_posts_title'				=> esc_html__( 'Recent Posts', 'raise-charity-pro' ),
		'recent_posts_sub_title'			=> esc_html__( 'Designs the experience in 3 steps, each increasing in detail, from the flow to the wireframes.', 'raise-charity-pro' ),
		'recent_posts_btn_text'				=> esc_html__( 'Read More', 'raise-charity-pro' ),
		'recent_posts_excerpt_length'		=> 15,

		// latest_products
		'latest_products_section_enable'	=> true,
		'latest_products_count'				=> 2,
		'latest_products_column_layout'		=> 'col-2',

		//popular products
		'popular_products_section_enable'	=> true,
		'popular_products_content_type'		=> 'product-category',
		'popular_products_count'			=> 4,
		'popular_products_title'			=> esc_html__( 'Womens Accessories', 'raise-charity-pro' ),
		'popular_products_sub_title'		=> esc_html__( 'Collections', 'raise-charity-pro' ),
		
		//products collection
		'collection_section_enable'			=> true,
		'collection_subtitle'				=> esc_html__( 'Limited', 'raise-charity-pro' ),
		'collection_title'					=> esc_html__( 'New Arrival', 'raise-charity-pro' ),

		//recent products
		'recent_products_section_enable'	=> true,
		'recent_products_content_type'		=> 'product-category',
		'recent_products_count'				=> 4,
		'recent_products_title'				=> esc_html__( 'Trending Outfits', 'raise-charity-pro' ),
		'recent_products_sub_title'			=> esc_html__( 'Recent', 'raise-charity-pro' ),

		//featured_products
		'featured_products_section_enable'		=> true,
		'featured_products_count'				=> 2,

		//trending_product 
		'trending_product_section_enable'				=> true,
		'trending_product_count'						=> 3,

	);

	$output = apply_filters( 'raise_charity_pro_default_theme_options', $raise_charity_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}