<?php
/**
 * CTA Section options
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */

// Add CTA section
$wp_customize->add_section( 'raise_charity_pro_cta_section', array(
	'title'             => esc_html__( 'CTA','raise-charity-pro' ),
	'description'       => esc_html__( 'CTA Section options.', 'raise-charity-pro' ),
	'panel'             => 'raise_charity_pro_front_page_panel',
) );

// CTA content enable control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Raise_Charity_Pro_Switch_Control( $wp_customize, 'raise_charity_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_cta_section',
	'on_off_label' 		=> raise_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[cta_section_enable]', array(
		'selector'            => '#call-to-action .tooltiptext',
		'settings'            => 'raise_charity_pro_theme_options[cta_section_enable]',
    ) );
}

// CTA content type control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[cta_content_type]', array(
	'default'          	=> $options['cta_content_type'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[cta_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_cta_section',
	'type'				=> 'select',
	'active_callback' 	=> 'raise_charity_pro_is_cta_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'raise-charity-pro' ),
		'post' 		=> esc_html__( 'Post', 'raise-charity-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'raise-charity-pro' ),
	),
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'raise_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_cta_section',
	'choices'			=> raise_charity_pro_page_choices(),
	'active_callback'	=> 'raise_charity_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[cta_content_post]', array(
	'sanitize_callback' => 'raise_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[cta_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_cta_section',
	'choices'			=> raise_charity_pro_post_choices(),
	'active_callback'	=> 'raise_charity_pro_is_cta_section_content_post_enable',
) ) );

// cta title setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[cta_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_title'],
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[cta_title]', array(
	'label'           	=> esc_html__( 'Title', 'raise-charity-pro' ),
	'section'        	=> 'raise_charity_pro_cta_section',
	'active_callback' 	=> 'raise_charity_pro_is_cta_section_content_custom_enable',
	'type'				=> 'text',
) );

// cta btn title setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[cta_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[cta_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'raise-charity-pro' ),
	'section'        	=> 'raise_charity_pro_cta_section',
	'active_callback' 	=> 'raise_charity_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[cta_btn_title]', array(
		'selector'            => '#call-to-action div.read-more a',
		'settings'            => 'raise_charity_pro_theme_options[cta_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'raise_charity_pro_cta_btn_title_partial',
    ) );
}

// cta btn link setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[cta_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[cta_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'raise-charity-pro' ),
	'section'        	=> 'raise_charity_pro_cta_section',
	'active_callback' 	=> 'raise_charity_pro_is_cta_section_content_custom_enable',
	'type'				=> 'url',
) );