<?php
/**
 * Featured Posts Section options
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */

// Add Featured Posts section
$wp_customize->add_section( 'raise_charity_pro_featured_posts_section', array(
	'title'             => esc_html__( 'Featured Posts','raise-charity-pro' ),
	'description'       => esc_html__( 'Featured Posts Section options.', 'raise-charity-pro' ),
	'panel'             => 'raise_charity_pro_front_page_panel',
) );

// Featured Posts content enable control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[featured_posts_section_enable]', array(
	'default'			=> 	$options['featured_posts_section_enable'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Raise_Charity_Pro_Switch_Control( $wp_customize, 'raise_charity_pro_theme_options[featured_posts_section_enable]', array(
	'label'             => esc_html__( 'Featured Posts Section Enable', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_featured_posts_section',
	'on_off_label' 		=> raise_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[featured_posts_section_enable]', array(
		'selector'            => '#featured-posts-section .tooltiptext',
		'settings'            => 'raise_charity_pro_theme_options[featured_posts_section_enable]',
    ) );
}

// content type control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[featured_posts_count]', array(
	'default'          	=> $options['featured_posts_count'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_number_range',
	'validate_callback' => 'raise_charity_pro_validate_featured_posts_count',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[featured_posts_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'raise-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 30. Please input the valid number and save. Then refresh the page to see the change.', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_featured_posts_section',
	'active_callback'   => 'raise_charity_pro_is_featured_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 30,
		'style' => 'width: 100px;'
		),
) );

// Featured Posts column layout control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[featured_posts_column_layout]', array(
	'default'          	=> $options['featured_posts_column_layout'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[featured_posts_column_layout]', array(
	'label'             => esc_html__( 'Column Layout', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_featured_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'raise_charity_pro_is_featured_posts_section_enable',
	'choices'			=> array(
		'col-2'      => esc_html__( 'Two Column', 'raise-charity-pro' ),
		'col-3'      => esc_html__( 'Three Column', 'raise-charity-pro' ),
		'col-4'      => esc_html__( 'Four Column', 'raise-charity-pro' ),
		),
) );

// Featured Posts content type control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[featured_posts_content_type]', array(
	'default'          	=> $options['featured_posts_content_type'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[featured_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_featured_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'raise_charity_pro_is_featured_posts_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'raise-charity-pro' ),
		'post'      => esc_html__( 'Post', 'raise-charity-pro' ),
		'category'  => esc_html__( 'Category', 'raise-charity-pro' ),
		),
) );

for ( $i = 1; $i <= $options['featured_posts_count']; $i++ ) :
	// latest_posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'raise_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'raise-charity-pro' ), $i ),
		'section'           => 'raise_charity_pro_featured_posts_section',
		'choices'			=> raise_charity_pro_page_choices(),
		'active_callback'	=> 'raise_charity_pro_is_featured_posts_section_content_page_enable',
	) ) );

	// latest_posts posts drop down chooser control and setting
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'raise_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'raise-charity-pro' ), $i ),
		'section'           => 'raise_charity_pro_featured_posts_section',
		'choices'			=> raise_charity_pro_post_choices(),
		'active_callback'	=> 'raise_charity_pro_is_featured_posts_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'raise_charity_pro_theme_options[featured_posts_content_category]', array(
	'sanitize_callback' => 'raise_charity_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'raise_charity_pro_theme_options[featured_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'raise-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_featured_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'raise_charity_pro_is_featured_posts_section_content_category_enable'
) ) );