<?php
/**
 * Popular Products Section options
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add recent_products section
$wp_customize->add_section( 'raise_charity_pro_popular_products_section', array(
    'title'             => esc_html__( 'Popular Products','raise-charity-pro' ),
    'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'raise-charity-pro' ),
    'panel'             => 'raise_charity_pro_front_page_panel',
) );

// recent_products content enable control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[popular_products_section_enable]', array(
    'default'           =>  $options['popular_products_section_enable'],
    'sanitize_callback' => 'raise_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Raise_Charity_Pro_Switch_Control( $wp_customize, 'raise_charity_pro_theme_options[popular_products_section_enable]', array(
    'label'             => esc_html__( 'Popular product Section Enable', 'raise-charity-pro' ),
    'section'           => 'raise_charity_pro_popular_products_section',
    'on_off_label'      => raise_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[popular_products_section_enable]', array(
        'selector'            => '#popular-products .tooltiptext',
        'settings'            => 'raise_charity_pro_theme_options[popular_products_section_enable]',
    ) );
}

// recent_products title setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[popular_products_sub_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['popular_products_sub_title'],       
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[popular_products_sub_title]', array(
    'label'             => esc_html__( 'SUb Title', 'raise-charity-pro' ),
    'section'           => 'raise_charity_pro_popular_products_section',
    'active_callback'   => 'raise_charity_pro_is_popular_products_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[popular_products_sub_title]', array(
        'selector'            => '#popular-products p.section-subtitle',
        'settings'            => 'raise_charity_pro_theme_options[popular_products_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'raise_charity_pro_popular_products_sub_title_partial',
    ) );
}

// recent_products title setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[popular_products_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['popular_products_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[popular_products_title]', array(
    'label'             => esc_html__( 'Title', 'raise-charity-pro' ),
    'section'           => 'raise_charity_pro_popular_products_section',
    'active_callback'   => 'raise_charity_pro_is_popular_products_section_enable',
    'type'              => 'text',
) );
// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[popular_products_title]', array(
        'selector'            => '#popular-products h2.section-title',
        'settings'            => 'raise_charity_pro_theme_options[popular_products_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'raise_charity_pro_popular_products_title_partial',
    ) );
}

$wp_customize->add_setting( 'raise_charity_pro_theme_options[popular_products_count]', array(
    'default'           => $options['popular_products_count'],
    'sanitize_callback' => 'raise_charity_pro_sanitize_number_range',
    'validate_callback' => 'raise_charity_pro_validate_popular_products_count',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[popular_products_count]', array(
    'label'             => esc_html__( 'Number of Products', 'raise-charity-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 30. Please input the valid number and save. Then refresh the page to see the change.', 'raise-charity-pro' ),
    'section'           => 'raise_charity_pro_popular_products_section',
    'active_callback'   => 'raise_charity_pro_is_popular_products_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 30,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'raise_charity_pro_theme_options[popular_products_content_type]', array(
    'default'           => $options['popular_products_content_type'],
    'sanitize_callback' => 'raise_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[popular_products_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'raise-charity-pro' ),
    'section'           => 'raise_charity_pro_popular_products_section',
    'type'              => 'select',
    'active_callback'   => 'raise_charity_pro_is_popular_products_section_enable',
    'choices'           => array(
        'product'           => esc_html__( 'Product', 'raise-charity-pro' ),
        'product-category'  => esc_html__( 'Product Category', 'raise-charity-pro' ),
        ),
) );

for( $i = 1 ; $i <= $options['popular_products_count']; $i++ ){

    $wp_customize->add_setting( 'raise_charity_pro_theme_options[popular_products_content_product_' . $i . ']', array(
        'sanitize_callback' => 'raise_charity_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[popular_products_content_product_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product %d', 'raise-charity-pro' ), $i ),
        'section'           => 'raise_charity_pro_popular_products_section',
        'choices'           => raise_charity_pro_product_choices(),
        'active_callback'   => 'raise_charity_pro_is_popular_products_section_content_product_enable',
    ) ) );
}

$wp_customize->add_setting(  'raise_charity_pro_theme_options[popular_products_content_product_category]', array(
        'sanitize_callback' => 'absint',
    ) ) ;

$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'raise_charity_pro_theme_options[popular_products_content_product_category]', array(
    'label'             => esc_html__( 'Select Product Categories', 'raise-charity-pro' ),
    'description'       => esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'raise-charity-pro' ),
    'section'           => 'raise_charity_pro_popular_products_section',
    'taxonomy'          => 'product_cat',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'raise_charity_pro_is_popular_products_section_content_product_category_enable',
) ) );
