<?php
/**
 * Recent Cause Section options
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */

// Add Recent Cause section
$wp_customize->add_section( 'raise_charity_pro_recent_cause_section', array(
	'title'             => esc_html__( 'Recent Cause','raise-charity-pro' ),
	'description'       => esc_html__( 'Recent Cause Section options.', 'raise-charity-pro' ),
	'panel'             => 'raise_charity_pro_front_page_panel',
) );

// Recent Cause content enable control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[recent_cause_section_enable]', array(
	'default'			=> 	$options['recent_cause_section_enable'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Raise_Charity_Pro_Switch_Control( $wp_customize, 'raise_charity_pro_theme_options[recent_cause_section_enable]', array(
	'label'             => esc_html__( 'Recent Cause Section Enable', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_recent_cause_section',
	'on_off_label' 		=> raise_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[recent_cause_section_enable]', array(
		'selector'            => '#recent-cause-section .tooltiptext',
		'settings'            => 'raise_charity_pro_theme_options[recent_cause_section_enable]',
    ) );
}

// Recent Cause section title setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[recent_cause_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_cause_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[recent_cause_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'raise-charity-pro' ),
	'section'        	=> 'raise_charity_pro_recent_cause_section',
	'active_callback' 	=> 'raise_charity_pro_is_recent_cause_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[recent_cause_title]', array(
		'selector'            => '#recent-cause-section h2.section-title',
		'settings'            => 'raise_charity_pro_theme_options[recent_cause_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'raise_charity_pro_recent_cause_title_partial',
    ) );
}

// Recent Cause section title setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[recent_cause_sub_title]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['recent_cause_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[recent_cause_sub_title]', array(
	'label'           	=> esc_html__( 'Section Sub Title', 'raise-charity-pro' ),
	'section'        	=> 'raise_charity_pro_recent_cause_section',
	'active_callback' 	=> 'raise_charity_pro_is_recent_cause_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[recent_cause_sub_title]', array(
		'selector'            => '#recent-cause-section p.section-subtitle',
		'settings'            => 'raise_charity_pro_theme_options[recent_cause_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'raise_charity_pro_recent_cause_sub_title_partial',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'raise_charity_pro_theme_options[recent_cause_excerpt_length]', array(
	'sanitize_callback' => 'raise_charity_pro_sanitize_number_range',
	'validate_callback' => 'raise_charity_pro_validate_long_excerpt',
	'default'			=> $options['recent_cause_excerpt_length'],
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[recent_cause_excerpt_length]', array(
	'label'       		=> esc_html__( 'Recent Cause Excerpt Length', 'raise-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in recent_cause posts.', 'raise-charity-pro' ),
	'section'     		=> 'raise_charity_pro_recent_cause_section',
	'active_callback' 	=> 'raise_charity_pro_is_recent_cause_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[recent_cause_count]', array(
	'default'          	=> $options['recent_cause_count'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_number_range',
	'validate_callback' => 'raise_charity_pro_validate_recent_cause_count',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[recent_cause_count]', array(
	'label'             => esc_html__( 'Number of recent causes posts', 'raise-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 30. Please input the valid number and save. Then refresh the page to see the change.', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_recent_cause_section',
	'active_callback'   => 'raise_charity_pro_is_recent_cause_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 30,
		'style' => 'width: 100px;'
		),
) );

// Recent Cause column layout control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[recent_cause_column_layout]', array(
	'default'          	=> $options['recent_cause_column_layout'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[recent_cause_column_layout]', array(
	'label'             => esc_html__( 'Column Layout', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_recent_cause_section',
	'type'				=> 'select',
	'active_callback' 	=> 'raise_charity_pro_is_recent_cause_section_enable',
	'choices'			=> array(
            'col-3'      => esc_html__( 'Three Column', 'raise-charity-pro' ),
            'col-4'      => esc_html__( 'Four Column', 'raise-charity-pro' ),
        )
) );

// Recent Cause btn label setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[recent_cause_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_cause_btn_label'],
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[recent_cause_btn_label]', array(
	'label'           	=> esc_html__( 'Recent Cause Button Label', 'raise-charity-pro' ),
	'section'        	=> 'raise_charity_pro_recent_cause_section',
	'active_callback' 	=> 'raise_charity_pro_is_recent_cause_section_enable',
	'type'				=> 'text',
) );

// Recent Cause content type control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[recent_cause_content_type]', array(
	'default'          	=> $options['recent_cause_content_type'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[recent_cause_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_recent_cause_section',
	'type'				=> 'select',
	'active_callback' 	=> 'raise_charity_pro_is_recent_cause_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'raise-charity-pro' ),
            'post'      => esc_html__( 'Post', 'raise-charity-pro' ),
            'category'  => esc_html__( 'Category', 'raise-charity-pro' ),
        )
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'raise_charity_pro_theme_options[recent_cause_content_category]', array(
	'sanitize_callback' => 'raise_charity_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'raise_charity_pro_theme_options[recent_cause_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'raise-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_recent_cause_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'raise_charity_pro_is_recent_cause_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['recent_cause_count']; $i++ ) :

	// recent_cause pages drop down chooser control and setting
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[recent_cause_content_page_' . $i . ']', array(
		'sanitize_callback' => 'raise_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[recent_cause_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'raise-charity-pro' ), $i ),
		'section'           => 'raise_charity_pro_recent_cause_section',
		'choices'			=> raise_charity_pro_page_choices(),
		'active_callback'	=> 'raise_charity_pro_is_recent_cause_section_content_page_enable',
	) ) );

	// recent_cause posts drop down chooser control and setting
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[recent_cause_content_post_' . $i . ']', array(
		'sanitize_callback' => 'raise_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[recent_cause_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'raise-charity-pro' ), $i ),
		'section'           => 'raise_charity_pro_recent_cause_section',
		'choices'			=> raise_charity_pro_post_choices(),
		'active_callback'	=> 'raise_charity_pro_is_recent_cause_section_content_post_enable',
	) ) );

endfor;