<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'raise_charity_pro_service_section', array(
	'title'             => esc_html__( 'Services','raise-charity-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'raise-charity-pro' ),
	'panel'             => 'raise_charity_pro_front_page_panel',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Raise_Charity_Pro_Switch_Control( $wp_customize, 'raise_charity_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_service_section',
	'on_off_label' 		=> raise_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[service_section_enable]', array(
		'selector'            => '#service-section .tooltiptext',
		'settings'            => 'raise_charity_pro_theme_options[service_section_enable]',
    ) );
}

// service title setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[service_title]',
	array(
		'default'       		=> $options['service_title'],
		'sanitize_callback'		=> 'sanitize_text_field',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'raise_charity_pro_theme_options[service_title]',
    array(
		'label'      			=> esc_html__( 'Section Title', 'raise-charity-pro' ),
		'section'    			=> 'raise_charity_pro_service_section',
		'type'		 			=> 'text',
		'active_callback'		=> 'raise_charity_pro_is_service_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[service_title]', array(
		'selector'            => '#service-section h2.section-title',
		'settings'            => 'raise_charity_pro_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'raise_charity_pro_service_title_partial',
    ) );
}

// service title setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[service_sub_title]',
	array(
		'default'       		=> $options['service_sub_title'],
		'sanitize_callback'		=> 'wp_kses_post',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'raise_charity_pro_theme_options[service_sub_title]',
    array(
		'label'      			=> esc_html__( 'Section Sub Title', 'raise-charity-pro' ),
		'section'    			=> 'raise_charity_pro_service_section',
		'type'		 			=> 'textarea',
		'active_callback'		=> 'raise_charity_pro_is_service_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[service_sub_title]', array(
		'selector'            => '#service-section p.section-subtitle',
		'settings'            => 'raise_charity_pro_theme_options[service_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'raise_charity_pro_service_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'raise_charity_pro_theme_options[service_image]', array(
		'sanitize_callback' => 'raise_charity_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'raise_charity_pro_theme_options[service_image]',
			array(
			'label'       		=> esc_html__( 'Service Image ', 'raise-charity-pro' ),
			'section'     		=> 'raise_charity_pro_service_section',
			'active_callback'	=> 'raise_charity_pro_is_service_section_enable',
	) ) );

// Servuce count number control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_number_range',
	'validate_callback' => 'raise_charity_pro_validate_service_count',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of services Posts', 'raise-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_service_section',
	'active_callback'   => 'raise_charity_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'raise_charity_pro_theme_options[service_excerpt_length]', array(
	'sanitize_callback' => 'raise_charity_pro_sanitize_number_range',
	'validate_callback' => 'raise_charity_pro_validate_long_excerpt',
	'default'			=> $options['service_excerpt_length'],
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[service_excerpt_length]', array(
	'label'       		=> esc_html__( 'Service Excerpt Length', 'raise-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in service posts.', 'raise-charity-pro' ),
	'section'     		=> 'raise_charity_pro_service_section',
	'active_callback' 	=> 'raise_charity_pro_is_service_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Service content type control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'raise_charity_pro_is_service_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'raise-charity-pro' ),
            'post'      => esc_html__( 'Post', 'raise-charity-pro' ),
            'category'  => esc_html__( 'Category', 'raise-charity-pro' ),
        ),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Raise_Charity_Pro_Icon_Picker( $wp_customize, 'raise_charity_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'raise-charity-pro' ), $i ),
		'section'           => 'raise_charity_pro_service_section',
		'active_callback'	=> 'raise_charity_pro_is_service_section_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'raise_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'raise-charity-pro' ), $i ),
		'section'           => 'raise_charity_pro_service_section',
		'choices'			=> raise_charity_pro_page_choices(),
		'active_callback'	=> 'raise_charity_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'raise_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'raise-charity-pro' ), $i ),
		'section'           => 'raise_charity_pro_service_section',
		'choices'			=> raise_charity_pro_post_choices(),
		'active_callback'	=> 'raise_charity_pro_is_service_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'raise_charity_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'raise_charity_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'raise_charity_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'raise-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'raise_charity_pro_is_service_section_content_category_enable'
) ) );