<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'raise_charity_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','raise-charity-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'raise-charity-pro' ),
	'panel'             => 'raise_charity_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Raise_Charity_Pro_Switch_Control( $wp_customize, 'raise_charity_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_slider_section',
	'on_off_label' 		=> raise_charity_pro_switch_options(),
) ) );

if( in_array( $options['home_layout'], array( 'all-design', 'default-design', 'second-design', 'third-design', 'fifth-design', 'sixth-design' )) ){ 

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[slider_section_enable]', array(
		'selector'            => '#featured-slider-section .tooltiptext',
		'settings'            => 'raise_charity_pro_theme_options[slider_section_enable]',
    ) );
}

}

if( in_array( $options['home_layout'], array( 'fourth-design', 'seventh-design' )) ){

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[slider_section_enable]', array(
		'selector'            => '#blog-slider-section .tooltiptext',
		'settings'            => 'raise_charity_pro_theme_options[slider_section_enable]',
    ) );
}

}

// Slider content enable control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Raise_Charity_Pro_Switch_Control( $wp_customize, 'raise_charity_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_slider_section',
	'on_off_label' 		=> raise_charity_pro_switch_options(),
	'active_callback' 	=> 'raise_charity_pro_is_slider_section_enable',
) ) );

// Slider btn label setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[slider_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[slider_btn_label]', array(
	'label'           	=> esc_html__( 'Slider Button Label', 'raise-charity-pro' ),
	'section'        	=> 'raise_charity_pro_slider_section',
	'active_callback' 	=> 'raise_charity_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[slider_btn_label]', array(
		'selector'            => '#featured-slider-section .read-more a.first',
		'settings'            => 'raise_charity_pro_theme_options[slider_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'raise_charity_pro_slider_btn_label_partial',
    ) );
}

if( ! in_array( $options['home_layout'], array( 'fourth-design', 'seventh-design' )) ){

// long Excerpt length setting and control.
$wp_customize->add_setting( 'raise_charity_pro_theme_options[slider_excerpt_length]', array(
	'sanitize_callback' => 'raise_charity_pro_sanitize_number_range',
	'validate_callback' => 'raise_charity_pro_validate_long_excerpt',
	'default'			=> $options['slider_excerpt_length'],
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[slider_excerpt_length]', array(
	'label'       		=> esc_html__( 'Slider Excerpt Length', 'raise-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in slider posts.', 'raise-charity-pro' ),
	'section'     		=> 'raise_charity_pro_slider_section',
	'active_callback' 	=> 'raise_charity_pro_is_slider_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

}

// Event social icons number control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_number_range',
	'validate_callback' => 'raise_charity_pro_validate_slider_count',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'raise-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 20. Please input the valid number and save. Then refresh the page to see the change.', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_slider_section',
	'active_callback'   => 'raise_charity_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 20,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'raise_charity_pro_is_slider_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'raise-charity-pro' ),
            'post'      => esc_html__( 'Post', 'raise-charity-pro' ),
            'category'  => esc_html__( 'Category', 'raise-charity-pro' ),
        )
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'raise_charity_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'raise_charity_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'raise_charity_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'raise-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'raise_charity_pro_is_slider_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'raise_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'raise-charity-pro' ), $i ),
		'section'           => 'raise_charity_pro_slider_section',
		'choices'			=> raise_charity_pro_page_choices(),
		'active_callback'	=> 'raise_charity_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'raise_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'raise-charity-pro' ), $i ),
		'section'           => 'raise_charity_pro_slider_section',
		'choices'			=> raise_charity_pro_post_choices(),
		'active_callback'	=> 'raise_charity_pro_is_slider_section_content_post_enable',
	) ) );

	if( ! in_array( $options['home_layout'], array( 'fourth-design', 'seventh-design' )) ){
		
	// Alt btn label setting and control
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[slider_alt_btn_label_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

	$wp_customize->add_control( 'raise_charity_pro_theme_options[slider_alt_btn_label_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Alternative Button Label %d', 'raise-charity-pro' ), $i ),
		'section'        	=> 'raise_charity_pro_slider_section',
		'active_callback' 	=> 'raise_charity_pro_is_slider_section_enable',
		'type'				=> 'text',
		) );

	// Slider btn label setting and control
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[slider_alt_btn_url_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

	$wp_customize->add_control( 'raise_charity_pro_theme_options[slider_alt_btn_url_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Alternative Button Link %d', 'raise-charity-pro' ), $i ),
		'section'        	=> 'raise_charity_pro_slider_section',
		'active_callback' 	=> 'raise_charity_pro_is_slider_section_enable',
		'type'				=> 'url',
		) );
	}

endfor;