<?php
/**
 * Courses section
 *
 * This is the template for the content of courses section
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */
if ( ! function_exists( 'raise_charity_pro_add_courses_section' ) ) :
    /**
    * Add courses section
    *
    *@since Raise Charity Pro 1.0.0
    */
    function raise_charity_pro_add_courses_section() {
        $options = raise_charity_pro_get_theme_options();
        // Check if courses is enabled on frontpage
        $courses_enable = apply_filters( 'raise_charity_pro_section_status', true, 'courses_section_enable' );

        if ( true !== $courses_enable ) {
            return false;
        }
        // Get courses section details
        $section_details = array();
        $section_details = apply_filters( 'raise_charity_pro_filter_courses_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render courses section now.
        raise_charity_pro_render_courses_section( $section_details );
    }
endif;

if ( ! function_exists( 'raise_charity_pro_get_courses_section_details' ) ) :
    /**
    * courses section details.
    *
    * @since Raise Charity Pro 1.0.0
    * @param array $input courses section details.
    */
    function raise_charity_pro_get_courses_section_details( $input ) {
        $options = raise_charity_pro_get_theme_options();

        // Content type.
        $courses_content_type  = $options['courses_content_type'];
        $courses_count = !empty( $options['courses_count'] ) ? $options['courses_count'] : 3;
        $content = array();
        switch ( $courses_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $courses_count; $i++ ) {
                    if ( ! empty( $options['courses_content_page_' . $i] ) ) :
                        $page_ids[] = $options['courses_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $courses_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $courses_count; $i++ ) {
                    if ( ! empty( $options['courses_content_post_' . $i] ) ) :
                        $post_ids[] = $options['courses_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $courses_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['courses_content_category'] ) ? $options['courses_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $courses_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = raise_charity_pro_trim_content( $options['courses_excerpt_length'] );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// courses section content details.
add_filter( 'raise_charity_pro_filter_courses_section_details', 'raise_charity_pro_get_courses_section_details' );


if ( ! function_exists( 'raise_charity_pro_render_courses_section' ) ) :
  /**
   * Start courses section
   *
   * @return string courses content
   * @since Raise Charity Pro 1.0.0
   *
   */
   function raise_charity_pro_render_courses_section( $content_details = array() ) {
        $options = raise_charity_pro_get_theme_options();

        $section_title = !empty( $options['courses_title'] ) ? $options['courses_title'] : '';
        $section_sub_title = !empty( $options['courses_sub_title'] ) ? $options['courses_sub_title'] : '';
        $btn = !empty( $options['courses_btn_text'] ) ? $options['courses_btn_text'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="raise_charity_pro_courses_section">
               <div id="course-section" class="relative page-section">
                <div class="wrapper">
                <?php if ( is_customize_preview()):
                    raise_charity_pro_section_tooltip( 'course-section' );
                    endif; ?>
                    <div class="section-header">
                    <?php if( !empty( $section_title ) ): ?>
                        <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
                    <?php endif;
                            if( !empty( $section_sub_title ) ):
                     ?>
                        <p class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></p>
                    <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content col-3 clear">
                       
                        <?php foreach ( $content_details as $content ) : ?>

                       <article>
                            <div class="course-item">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->


                                    <?php if( !empty( $btn ) ): ?>

                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $btn ); ?></a>
                                    </div><!-- .read-more -->

                                <?php endif; ?>
                                </div><!-- .entry-container -->
                            </div><!-- .course-item -->
                        </article>

                        <?php endforeach; ?>


                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #course-section -->
        </div>
     

    <?php }
endif;