<?php
/**
 * Event section
 *
 * This is the template for the content of event section
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */
if ( ! function_exists( 'raise_charity_pro_add_event_section' ) ) :
    /**
    * Add event section
    *
    *@since Raise Charity Pro 1.0.0
    */
    function raise_charity_pro_add_event_section() {
        $options = raise_charity_pro_get_theme_options();
        // Check if event is enabled on frontpage
        $event_enable = apply_filters( 'raise_charity_pro_section_status', true, 'event_section_enable' );

        if ( true !== $event_enable ) {
            return false;
        }
        // Get event section details
        $section_details = array();
        $section_details = apply_filters( 'raise_charity_pro_filter_event_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render event section now.
        raise_charity_pro_render_event_section( $section_details );
    }
endif;

if ( ! function_exists( 'raise_charity_pro_get_event_section_details' ) ) :
    /**
    * event section details.
    *
    * @since Raise Charity Pro 1.0.0
    * @param array $input event section details.
    */
    function raise_charity_pro_get_event_section_details( $input ) {
        $options = raise_charity_pro_get_theme_options();

        // Content type.
        $event_content_type  = $options['event_content_type'];
        $event_count  = ! empty( $options['event_count'] ) ? $options['event_count'] : 4;
        
        $content = array();
        switch ( $event_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_page_' . $i] ) )
                        $page_ids[] = $options['event_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $event_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_post_' . $i] ) )
                        $post_ids[] = $options['event_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => $event_count,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['event_content_category'] ) ? $options['event_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => $event_count,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = raise_charity_pro_trim_content( $options['event_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// event section content details.
add_filter( 'raise_charity_pro_filter_event_section_details', 'raise_charity_pro_get_event_section_details' );


if ( ! function_exists( 'raise_charity_pro_render_event_section' ) ) :
  /**
   * Start event section
   *
   * @return string event content
   * @since Raise Charity Pro 1.0.0
   *
   */
function raise_charity_pro_render_event_section( $content_details = array() ) {
    $options = raise_charity_pro_get_theme_options();
    $event_title = ! empty( $options['event_title'] ) ? $options['event_title'] : '';
    $event_sub_title = ! empty( $options['event_sub_title'] ) ? $options['event_sub_title'] : '';

    if ( empty( $content_details ) ) {
        return;
    } 
    ?> 
    <div id="raise_charity_pro_event_section">
        <div id="event-section" class="relative page-section">
                <div class="wrapper">
                  <?php if ( is_customize_preview()):
                  raise_charity_pro_section_tooltip( 'event-section' );
                  endif; ?>
                    <div class="section-header">
                        <?php if( !empty( $event_title ) ): ?>
                            <h2 class="section-title"><?php echo esc_html( $event_title ); ?></h2>
                        <?php endif;
                        if( !empty( $event_sub_title ) ):
                         ?>
                     <p class="section-subtitle"><?php echo esc_html( $event_sub_title ); ?></p>
                 <?php endif; ?>

                 </div><!-- .section-header -->

                 <div class="section-content clear">

                    <?php foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="event-wrapper">
                                <div class="entry-container">
                                    <?php raise_charity_pro_posted_on( $content['id'] ); ?>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .event-wrapper -->
                        </article>

                    <?php endforeach; ?>

                </div><!-- .col-2 -->
            </div><!-- .wrapper -->
        </div><!-- #event-section -->
    </div>
    

<?php }
endif;