<?php
/**
 * Gallery section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */
if ( ! function_exists( 'raise_charity_pro_add_gallery_section' ) ) :
    /**
    * Add gallery section
    *
    *@since Raise Charity Pro 1.0.0
    */
    function raise_charity_pro_add_gallery_section() {
        $options = raise_charity_pro_get_theme_options();
        // Check if gallery is enabled on frontpage
        $gallery_enable = apply_filters( 'raise_charity_pro_section_status', true, 'gallery_section_enable' );

        if ( true !== $gallery_enable ) {
            return false;
        }
        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'raise_charity_pro_filter_gallery_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render gallery section now.
        raise_charity_pro_render_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'raise_charity_pro_get_gallery_section_details' ) ) :
    /**
    * gallery section details.
    *
    * @since Raise Charity Pro 1.0.0
    * @param array $input gallery section details.
    */
    function raise_charity_pro_get_gallery_section_details( $input ) {
        $options = raise_charity_pro_get_theme_options();

        // Content type.
        $gallery_content_type  = $options['gallery_content_type'];
        $gallery_count = ! empty( $options['gallery_count'] ) ? $options['gallery_count'] : 9;
        $content = array();
        switch ( $gallery_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_page_' . $i] ) ) :
                        $page_ids[] = $options['gallery_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_post_' . $i] ) ) :
                        $post_ids[] = $options['gallery_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['gallery_content_category'] ) ? $options['gallery_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $gallery_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// gallery section content details.
add_filter( 'raise_charity_pro_filter_gallery_section_details', 'raise_charity_pro_get_gallery_section_details' );


if ( ! function_exists( 'raise_charity_pro_render_gallery_section' ) ) :
  /**
   * Start gallery section
   *
   * @return string gallery content
   * @since Raise Charity Pro 1.0.0
   *
   */
   function raise_charity_pro_render_gallery_section( $content_details = array() ) {
        $options = raise_charity_pro_get_theme_options();
        $gallery_title = ! empty( $options['gallery_title'] ) ? $options['gallery_title'] : '';
        $gallery_sub_title = ! empty( $options['gallery_subtitle'] ) ? $options['gallery_subtitle'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="raise_charity_pro_gallery_section">
             <div id="gallery-section" class="relative page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    raise_charity_pro_section_tooltip( 'gallery-section' );
                    endif; ?>
                    <div class="section-header">
                        <?php if( !empty( $gallery_title ) ): ?>
                                <h2 class="section-title"><?php echo esc_html( $gallery_title ); ?></h2>
                            <?php endif;
                            if( !empty( $gallery_sub_title ) ):
                               ?>
                           <p class="section-subtitle"><?php echo esc_html( $gallery_sub_title ); ?></p>
                       <?php endif; ?>
                   </div><!-- .section-header -->

                   <div class="section-content col-3 clear">

                    <?php foreach ($content_details as $content ): ?>

                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                            </div><!-- .featured-image -->
                        </article>

                    <?php endforeach; ?>

                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #gallery-section -->
        </div>
           
        
    <?php }
endif;