<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */
if ( ! function_exists( 'raise_charity_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Raise Charity Pro 1.0.0
    */
    function raise_charity_pro_add_slider_section() {
    	$options = raise_charity_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'raise_charity_pro_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'raise_charity_pro_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        raise_charity_pro_render_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'raise_charity_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Raise Charity Pro 1.0.0
    * @param array $input slider section details.
    */
    function raise_charity_pro_get_slider_section_details( $input ) {
        $options = raise_charity_pro_get_theme_options();

        // Content type.
        $slider_content_type  = $options['slider_content_type'];
        $slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 3;
        $content = array();
        switch ( $slider_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $slider_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = raise_charity_pro_trim_content( $options['slider_excerpt_length'] );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'raise_charity_pro_filter_slider_section_details', 'raise_charity_pro_get_slider_section_details' );


if ( ! function_exists( 'raise_charity_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Raise Charity Pro 1.0.0
   *
   */
   function raise_charity_pro_render_slider_section( $content_details = array() ) {
        $options = raise_charity_pro_get_theme_options();
        $btn_label = ! empty( $options['slider_btn_label'] ) ? $options['slider_btn_label'] : '';
        $autoplay = $options['slider_autoplay'] ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="raise_charity_pro_slider_section">
             <?php if( in_array( $options['home_layout'], array( 'all-design', 'default-design', 'second-design', 'third-design', 'fifth-design', 'sixth-design' )) ){ ?>
        
        <div id="featured-slider-section" class="slider-section">
            <div class="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows":false, "autoplay": <?php echo esc_attr( $autoplay ); ?>, "draggable": true, "fade": false, "adaptiveHeight": true }'>

                <?php $i = 1; foreach ($content_details as $content ) : ?>

                    <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                        <div class="overlay"></div>
                        <div class="wrapper">
                            <?php if ( is_customize_preview()):
                            raise_charity_pro_section_tooltip( 'featured-slider-section' );
                            endif; ?>
                            
                            <div class="featured-content-wrapper">
                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <div class="read-more">
                                        <?php if( !empty( $btn_label ) ): ?>
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="first btn"><?php echo esc_html( $btn_label ); ?></a>
                                        <?php endif; ?>

                                        <?php if( !empty( $options['slider_alt_btn_url_'.$i] ) && !empty( $options['slider_alt_btn_label_'.$i] ) ): ?>
                                            <a href="<?php echo esc_url( $options['slider_alt_btn_url_'.$i] ); ?>" class="btn"><?php echo esc_html( $options['slider_alt_btn_label_'.$i] ); ?></a>
                                        <?php endif; ?>
                                    </div><!-- .read-more -->
                                </div><!-- .entry-container -->
                            </div><!-- .featured-content-wrapper -->
                        </div><!-- .wrapper -->

                    </article>

                <?php $i++; endforeach; ?>

            </div><!-- .featured-slider -->
        </div><!-- #featured-slider-section -->

        <?php } ?>

         <?php if( in_array( $options['home_layout'], array( 'fourth-design', 'seventh-design' )) ){ ?>

         <div id="blog-slider-section" class="slider-section">
                <div class="blog-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows":false, "autoplay": <?php echo esc_attr( $autoplay ); ?>, "draggable": true, "fade": false, "adaptiveHeight": true }'>
                    
                    <?php foreach ($content_details as $content ) : ?>

                    <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                        <div class="overlay"></div>
                        <div class="wrapper">
                        <?php if ( is_customize_preview()):
                            raise_charity_pro_section_tooltip( 'blog-slider-section' );
                            endif; ?>
                            <div class="blog-content-wrapper">
                                <div class="entry-container">
                                    <div class="entry-meta">
                                    <?php if( $options['home_layout'] !== 'seventh-design' ){ ?>
                                        <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span><!-- .cat-links -->
                                        <?php } ?>

                                        <?php raise_charity_pro_posted_on( $content['id'] ); ?>
                                    </div><!-- .entry-meta -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <?php if( !empty( $btn_label ) ): ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $btn_label ); ?></a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                                
                                </div><!-- .entry-container -->
                            </div><!-- .blog-content-wrapper -->
                        </div><!-- .wrapper -->
                    </article>

                    <?php endforeach; ?>

                </div><!-- .blog-slider -->
            </div><!-- #blog-slider-section -->

         <?php } ?>
        </div>
       

    <?php }
endif;